# libpythonpro2
Módulo para exemplificar a construção de projetos Python no curso Pytools

Neste curso é ensinado como contribuir em projetos de código aberto

Link para o curso [Python Pro](https://www.python.pro.br)

[![Build Status](https://travis-ci.com/RicardoHMoreno/libpythonpro2.svg?branch=main)](https://travis-ci.com/RicardoHMoreno/libpythonpro2)
[![Updates](https://pyup.io/repos/github/RicardoHMoreno/libpythonpro2/shield.svg)](https://pyup.io/repos/github/RicardoHMoreno/libpythonpro2/)
[![Python 3](https://pyup.io/repos/github/RicardoHMoreno/libpythonpro2/python-3-shield.svg)](https://pyup.io/repos/github/RicardoHMoreno/libpythonpro2/)

Suportada versão 3 de Python

Para instalar:

````console no windows
C:\...\libpythonpro>py -3 -m venv .venv
C:\...\libpythonpro\.venv\Scripts\activate.bat
(.venv)C:\...\libpythonpro>pip install -r requirements-dev.txt
````

Para conferir qualidade de código:

````console no windows
(.venv)C:\...\libpythonpro>flake8
````
Tópicos a serem abordados:
 1. Git
 2. Virtualenv
 3. Pip
